AgentWorkspaceEnvironment

Struct AgentWorkspaceEnvironment 

pub struct AgentWorkspaceEnvironment {
    pub environment: ExecutionEnvironment,
    pub egress_allowlist: Option<EgressAllowlist>,
}
Lowered toolkit environment profile.

Fields

environment: ExecutionEnvironment

Canonical core execution environment.

egress_allowlist: Option<EgressAllowlist>

Optional toolkit egress allowlist that produced the network policy.

Implementations

Source

impl AgentWorkspaceEnvironment

pub fn environment(&self) -> &ExecutionEnvironment

Returns the canonical core execution environment.

pub fn into_environment(self) -> ExecutionEnvironment

Consumes this profile into the canonical core execution environment.

pub fn egress_allowlist(&self) -> Option<&EgressAllowlist>

Returns the optional egress allowlist that produced the network policy.

pub fn isolation_snapshot( &self, sidecar_id: RuntimePackageSidecarId, redaction_policy_ref: PolicyRef, cleanup_policy_ref: PolicyRef, child_lifecycle_policy_ref: PolicyRef, ) -> IsolationRequirementSnapshot

Builds an isolation requirement snapshot for attachment to a RuntimePackage.

pub fn default_isolation_snapshot(&self) -> IsolationRequirementSnapshot

Builds an isolation snapshot using conservative toolkit policy refs.