AgentTraceEvaluation

Struct AgentTraceEvaluation 

pub struct AgentTraceEvaluation { /* private fields */ }
Builder for evaluating an agent trace with an arbitrary evaluator.

Implementations

Source

impl AgentTraceEvaluation

pub fn turn( trace: &TurnTrace, expected_outcome: ExpectedOutcome, ) -> Result<Self, AgentError>

Builds an evaluation from a turn trace.

pub fn run( trace: &RunTrace, expected_outcome: ExpectedOutcome, ) -> Result<Self, AgentError>

Builds an evaluation from a run trace.

pub fn session( timeline: &SessionTimeline, expected_outcome: ExpectedOutcome, ) -> Result<Self, AgentError>

Builds an evaluation from a session timeline.

pub fn compare_sessions( observed: &SessionTimeline, baseline: &SessionTimeline, expected_outcome: ExpectedOutcome, ) -> Result<Self, AgentError>

Builds a deterministic comparison between two session timelines.

pub fn compare(self, comparison: ComparisonDesign) -> Self

Returns this evaluation with its comparison design replaced.

pub fn with_budget(self, budget: EvaluationBudget) -> Self

Returns this evaluation with its evaluator budget replaced.

pub fn evaluate<E: Evaluator>( &self, evaluator: &E, ) -> Result<EvaluationReport, AgentError>

Evaluates this trace using the supplied evaluator.

pub fn request(&self) -> &EvaluationRequest

Returns the request this builder will evaluate.

pub fn evidence(&self) -> &EvidenceBundle

Returns the evidence bundle this builder will pass to the evaluator.

pub fn metrics(&self) -> &TraceMetrics

Returns deterministic metrics for the observed trace.

pub fn metrics_comparison(&self) -> Option<&TraceMetricsComparison>

Returns deterministic comparison metrics when this evaluation compares traces.