Module protocol

Module protocol 

Deterministic protocol conformance harnesses for SDK consumers.

Structs

IsolatedJsonRpcProcess
In-memory isolated json rpc process fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.
McpHostProxy
In-memory mcp host proxy fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.
ScriptedAcpAgent
In-memory scripted acp agent fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.
ScriptedAcpClient
In-memory scripted acp client fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.
ScriptedMcpServer
In-memory scripted mcp server fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.