pub struct ToolIdentity {
pub name: CanonicalToolName,
pub version: String,
pub capability_id: CapabilityId,
pub namespace: CapabilityNamespace,
pub executor_ref: ExecutorRef,
pub schema_ref: PackageSidecarRef,
}Expand description
Stable identity for a typed tool declaration.
Fields
name: CanonicalToolNameProvider-visible canonical tool name.
version: StringTool version.
capability_id: CapabilityIdRuntime package capability id.
namespace: CapabilityNamespaceCapability namespace.
executor_ref: ExecutorRefExecutor ref registered in the runtime.
schema_ref: PackageSidecarRefSchema sidecar ref used by provider projection and fingerprints.
Implementations
Sourceimpl ToolIdentity
impl ToolIdentity
Sourcepub fn new(
name: impl Into<String>,
version: impl Into<String>,
) -> Result<Self, AgentError>
pub fn new( name: impl Into<String>, version: impl Into<String>, ) -> Result<Self, AgentError>
Creates a deterministic typed tool identity from name and version.
Sourcepub fn capability_id(self, id: CapabilityId) -> Self
pub fn capability_id(self, id: CapabilityId) -> Self
Sets an explicit capability id.
Sourcepub fn executor_ref(self, executor_ref: ExecutorRef) -> Self
pub fn executor_ref(self, executor_ref: ExecutorRef) -> Self
Sets an explicit executor ref.
Sourcepub fn schema_ref(self, schema_ref: PackageSidecarRef) -> Self
pub fn schema_ref(self, schema_ref: PackageSidecarRef) -> Self
Sets an explicit schema ref.