pub enum WorkspaceFileKind {
Text,
Markdown,
Json,
Pdf,
Image,
RawImage,
OfficeDocument,
Archive,
SqliteDatabase,
UrlResource,
Binary,
}Expand description
Enumerates the finite workspace file kind cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
Text
Use this variant when the contract needs to represent text; selecting it has no side effect by itself.
Markdown
Use this variant when the contract needs to represent markdown; selecting it has no side effect by itself.
Json
Use this variant when the contract needs to represent json; selecting it has no side effect by itself.
Use this variant when the contract needs to represent pdf; selecting it has no side effect by itself.
Image
Use this variant when the contract needs to represent image; selecting it has no side effect by itself.
RawImage
Use this variant when the contract needs to represent raw image; selecting it has no side effect by itself.
OfficeDocument
Use this variant when the contract needs to represent office document; selecting it has no side effect by itself.
Archive
Use this variant when the contract needs to represent archive; selecting it has no side effect by itself.
SqliteDatabase
Use this variant when the contract needs to represent sqlite database; selecting it has no side effect by itself.
UrlResource
Use this variant when the contract needs to represent url resource; selecting it has no side effect by itself.
Binary
Use this variant when the contract needs to represent binary; selecting it has no side effect by itself.