pub enum WorkspaceWriteMode {
CreateNew,
Overwrite,
}Expand description
Enumerates the finite workspace write mode cases. Serialized names are part of the SDK contract; update fixtures when variants change.
Variants
CreateNew
Use this variant when the contract needs to represent create new; selecting it has no side effect by itself.
Overwrite
Use this variant when the contract needs to represent overwrite; selecting it has no side effect by itself.