Deterministic protocol conformance harnesses for SDK consumers.
Structs
- Isolated
Json RpcProcess - In-memory isolated json rpc process fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.
- McpHost
Proxy - In-memory mcp host proxy fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.
- Scripted
AcpAgent - In-memory scripted acp agent fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.
- Scripted
AcpClient - In-memory scripted acp client fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.
- Scripted
McpServer - In-memory scripted mcp server fixture for SDK conformance tests. Use it to script deterministic behavior in memory; any transcript or endpoint mutation is documented on the method that performs it.