TypedTool

Struct TypedTool 

pub struct TypedTool<A: ToolArgs, R: ToolOutput> { /* private fields */ }
Typed tool declaration plus handler adapter.

Implementations

Source

impl<A: ToolArgs, R: ToolOutput> TypedTool<A, R>

pub fn builder(identity: ToolIdentity) -> TypedToolBuilder<A, R>

Starts a typed tool builder.

pub fn schema_snapshot(&self) -> &ToolSchemaSnapshot

Returns the schema snapshot.

pub fn require_approval(self) -> Self

Marks this tool as requiring host approval before execution.

pub fn approval_required(&self) -> bool

Returns whether approval is required for this tool.

pub fn tool(&self) -> Result<Tool, AgentError>

Lowers to an ergonomic toolkit tool declaration.

pub fn async_tool(&self) -> Result<AsyncTool, AgentError>

Lowers to an ergonomic async toolkit declaration.

pub fn executor( &self, args: Arc<dyn JsonToolArgumentStore>, out: Arc<dyn JsonToolContentStore>, ) -> Arc<dyn ToolExecutor>

Creates a core tool executor adapter for this typed tool.

pub fn pack_bundle( &self, source: SourceRef, ) -> Result<ToolkitPackBundle, AgentError>

Builds a toolkit pack bundle containing this tool declaration.